Nback Model
===========

**"When Working Memory is Just Working, Not Memory"** (`Beukers et al., 2022 <https://psyarxiv.com/jtw5p>`_)

Script: :download:`nback.py <../../Scripts/Models (Under Development)/Beukers_et_al_2022/nback.py>`

Example of Jupyter Notebook: `BeukersNBackModel_NB`

(Instructions for running the actual notebook can be found `here <Tutorial>`, replacing ``nback_nb`` for ``tutorial``)

.. toctree::
   :maxdepth: 1

   `Jupyter Notebook <../../Scripts/Models (Under Development)/Beukers_et_al_2022/nback_nb.ipynb>`


.. automodule:: psyneulink.library.models.Beukers_et_al_2022.nback
   :members: construct_model, train_network, run_model, analyze_results


